@@ -32,13 +32,13 @@
 #include "kbuildservicefactory_p.h"
 #include "kbuildservicegroupfactory_p.h"
 #include "kctimefactory_p.h"
-#include <QtCore/QDataStream>
-#include <QtCore/QDir>
-#include <QtCore/QEventLoop>
-#include <QtCore/QFile>
-#include <QtCore/QLocale>
-#include <QtCore/QTimer>
-#include <QtCore/QDebug>
+#include <QDataStream>
+#include <QDir>
+#include <QEventLoop>
+#include <QFile>
+#include <QLocale>
+#include <QTimer>
+#include <QDebug>
 #include <QDirIterator>
 #include <QDateTime>
 #include <qsavefile.h>
@@ -202,6 +202,7 @@ bool KBuildSycoca::build()
 
         QSet<QString> relFiles;
         const QStringList dirs = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, m_resourceSubdir, QStandardPaths::LocateDirectory);
+        qCDebug(SYCOCA) << "Looking for subdir" << m_resourceSubdir << "=>" << dirs;
         Q_FOREACH (const QString &dir, dirs) {
             QDirIterator it(dir, QDirIterator::Subdirectories);
             while (it.hasNext()) {
@@ -245,24 +246,12 @@ bool KBuildSycoca::build()
         }
         if (m_changed || !m_allEntries) {
             //qCDebug(SYCOCA) << "CHANGED:" << m_resource;
-            m_changedResources.append(m_resource);
+            m_changedResources.append(QString::fromLatin1(m_resource));
         }
     }
 
-    if (m_ctimeDict && !m_ctimeDict->isEmpty()) {
-        //qCDebug(SYCOCA) << "Still in time dict:";
-        //m_ctimeDict->dump();
-        // ## It seems entries filtered out by vfolder are still in there,
-        // so on a real system we end up always adding "apps" to m_changedResources
-
-        // Get the list of resources from which some files were deleted
-        const QStringList resources = m_ctimeDict->remainingResourceList();
-        qCDebug(SYCOCA) << "Still in the time dict (i.e. deleted files)" << resources;
-        m_changedResources += resources;
-    }
-
     bool result = true;
-    const bool createVFolder = !m_changedResources.isEmpty() || (m_ctimeDict && !m_ctimeDict->isEmpty());
+    const bool createVFolder = true; // we need to always run the VFolderMenu code
     if (createVFolder || m_menuTest) {
         m_resource = "apps";
         m_resourceSubdir = QStringLiteral("applications");
@@ -284,7 +273,7 @@ bool KBuildSycoca::build()
         // Storing the mtime *after* looking at these dirs is a tiny race condition,
         // but I'm not sure how to get the vfolder dirs upfront...
         Q_FOREACH (QString dir, m_vfolder->allDirectories()) {
-            if (dir.endsWith('/')) {
+            if (dir.endsWith(QLatin1Char('/'))) {
                 dir.chop(1); // remove trailing slash, to avoid having ~/.local/share/applications twice
             }
             if (!m_allResourceDirs.contains(dir)) {
@@ -299,13 +288,23 @@ bool KBuildSycoca::build()
 
         if (m_changed || !m_allEntries) {
             //qCDebug(SYCOCA) << "CHANGED:" << m_resource;
-            m_changedResources.append(m_resource);
+            m_changedResources.append(QString::fromLatin1(m_resource));
         }
         if (m_menuTest) {
             result = false;
         }
     }
 
+    if (m_ctimeDict && !m_ctimeDict->isEmpty()) {
+        qCDebug(SYCOCA) << "Still in time dict:";
+        m_ctimeDict->dump();
+
+        // Get the list of resources from which some files were deleted
+        QStringList resources = m_ctimeDict->remainingResourceList();
+        qCDebug(SYCOCA) << "Still in the time dict (i.e. deleted files)" << resources;
+        m_changedResources += resources;
+    }
+
     qDeleteAll(entryDictList);
     return result;
 }
@@ -315,7 +314,7 @@ void KBuildSycoca::createMenu(const QString &caption_, const QString &name_, VFo
     QString caption = caption_;
     QString name = name_;
     foreach (VFolderMenu::SubMenu *subMenu, menu->subMenus) {
-        QString subName = name + subMenu->name + '/';
+        QString subName = name + subMenu->name + QLatin1Char('/');
 
         QString directoryFile = subMenu->directoryFile;
         if (directoryFile.isEmpty()) {
@@ -347,14 +346,14 @@ void KBuildSycoca::createMenu(const QString &caption_, const QString &name_, VFo
         entry = m_buildServiceGroupFactory->addNew(subName, subMenu->directoryFile, entry, subMenu->isDeleted);
         entry->setLayoutInfo(subMenu->layoutList);
         if (!(m_menuTest && entry->noDisplay())) {
-            createMenu(caption + entry->caption() + '/', subName, subMenu);
+            createMenu(caption + entry->caption() + QLatin1Char('/'), subName, subMenu);
         }
     }
     if (caption.isEmpty()) {
-        caption += '/';
+        caption += QLatin1Char('/');
     }
     if (name.isEmpty()) {
-        name += '/';
+        name += QLatin1Char('/');
     }
     foreach (const KService::Ptr &p, menu->items) {
         if (m_menuTest) {
@@ -380,7 +379,7 @@ bool KBuildSycoca::recreate(bool incremental)
     if (!lockFile.tryLock()) {
         qCDebug(SYCOCA) <<  "Waiting for already running" << KBUILDSYCOCA_EXENAME << "to finish.";
         if (!lockFile.lock()) {
-            qCWarning(SYCOCA) << "Couldn't lock" << path + ".lock";
+            qCWarning(SYCOCA) << "Couldn't lock" << path + QStringLiteral(".lock");
             return false;
         }
         if (!needsRebuild()) {
@@ -450,8 +449,8 @@ bool KBuildSycoca::recreate(bool incremental)
         //as $HOME may also be that of another user rather than /root
 #ifdef Q_OS_UNIX
         if (qEnvironmentVariableIsSet("SUDO_UID")) {
-            const int uid = QString(qgetenv("SUDO_UID")).toInt();
-            const int gid = QString(qgetenv("SUDO_GID")).toInt();
+            const int uid = qgetenv("SUDO_UID").toInt();
+            const int gid = qgetenv("SUDO_GID").toInt();
             if (uid && gid) {
                 fchown(database.handle(), uid, gid);
             }
@@ -555,7 +554,7 @@ void KBuildSycoca::save(QDataStream *str)
         }
     }
 
-    int endOfData = str->device()->pos();
+    qint64 endOfData = str->device()->pos();
 
     // Write header (#pass 2)
     str->device()->seek(0);
@@ -648,7 +647,7 @@ bool KBuildSycoca::checkGlobalHeader()
     const QString current_prefixes = QStandardPaths::standardLocations(QStandardPaths::GenericDataLocation).join(QString(QLatin1Char(':')));
 
     const KSycocaHeader header = KSycocaPrivate::self()->readSycocaHeader();
-    Q_ASSERT(!header.prefixes.split(':').contains(QDir::homePath()));
+    Q_ASSERT(!header.prefixes.split(QLatin1Char(':')).contains(QDir::homePath()));
 
     return (current_update_sig == header.updateSignature) &&
             (current_language == header.language) &&
